Pyramid
=======

Pyramid is a small, fast, down-to-earth, open source Python web application
development framework. It makes real-world web application development and
deployment more fun, more predictable, and more productive.

Pyramid is the newest web framework produced by the `Pylons Project
<http://pylonsproject.org/>`_.

Pyramid was previously known as `repoze.bfg <http://bfg.repoze.org>`_.

Support and Documentation
-------------------------

See the `Pylons Project website <http://pylonsproject.org/>`_ to view
documentation, report bugs, and obtain support.

License
-------

Pyramid is offered under the BSD-derived `Repoze Public License
<http://repoze.org/license.html>`_.

Authors
-------

Pyramid is made available by `Agendaless Consulting <http://agendaless.com>`_
and a team of contributors.

